# OPAL Community Code of Conduct

OPAL follows the [CNCF Code of Conduct](https://github.com/cncf/foundation/blob/master/code-of-conduct.md).

Instances of abusive, harassing, or otherwise unacceptable behavior may be reported by contacting
the maintainers via <conduct@authorizon.com>.
